A wrapper around saveRDS to save nicheR_ellipsoid
or nicheR_community objects to a file. Includes a safety check
for overwriting existing files and ensures the file extension is .rds.
Arguments
- object
A
nicheR_ellipsoidornicheR_communityobject.- file
Character. The connection or name of the file where the object will be saved (usually ending in ".rds").
- overwrite
Logical. If
TRUE, an existing file at the specified path will be replaced. Default isFALSE.- ...
Additional arguments passed to
saveRDS.